@@ -32,6 +32,7 @@ import java.io.DataOutput;
 import java.io.DataOutputStream;
 import java.io.IOException;
 import java.security.MessageDigest;
+import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -108,16 +109,17 @@ import org.objectweb.asm.Opcodes;
  *
  * @author Rajendra Inamdar, Vishal Vishnoi
  */
+// DontCheck(AbbreviationAsWordInName): can't be renamed (for backward binary compatibility).
 public class SerialVersionUIDAdder extends ClassVisitor {
 
   /** The JVM name of static initializer methods. */
   private static final String CLINIT = "<clinit>";
 
   /** A flag that indicates if we need to compute SVUID. */
-  private boolean computeSVUID;
+  private boolean computeSvuid;
 
   /** Whether the class already has a SVUID. */
-  private boolean hasSVUID;
+  private boolean hasSvuid;
 
   /** The class access flags. */
   private int access;
@@ -149,7 +151,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    * @throws IllegalStateException If a subclass calls this constructor.
    */
   public SerialVersionUIDAdder(final ClassVisitor classVisitor) {
-    this(Opcodes.ASM6, classVisitor);
+    this(Opcodes.ASM7, classVisitor);
     if (getClass() != SerialVersionUIDAdder.class) {
       throw new IllegalStateException();
     }
@@ -159,8 +161,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    * Constructs a new {@link SerialVersionUIDAdder}.
    *
    * @param api the ASM API version implemented by this visitor. Must be one of {@link
-   *     Opcodes#ASM4}, {@link Opcodes#ASM5}, {@link Opcodes#ASM6} or {@link
-   *     Opcodes#ASM7_EXPERIMENTAL}.
+   *     Opcodes#ASM4}, {@link Opcodes#ASM5}, {@link Opcodes#ASM6} or {@link Opcodes#ASM7}.
    * @param classVisitor a {@link ClassVisitor} to which this visitor will delegate calls.
    */
   protected SerialVersionUIDAdder(final int api, final ClassVisitor classVisitor) {
@@ -181,9 +182,9 @@ public class SerialVersionUIDAdder extends ClassVisitor {
       final String[] interfaces) {
     // Get the class name, access flags, and interfaces information (step 1, 2 and 3) for SVUID
     // computation.
-    computeSVUID = (access & Opcodes.ACC_ENUM) == 0;
+    computeSvuid = (access & Opcodes.ACC_ENUM) == 0;
 
-    if (computeSVUID) {
+    if (computeSvuid) {
       this.name = name;
       this.access = access;
       this.interfaces = new String[interfaces.length];
@@ -205,7 +206,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
       final String[] exceptions) {
     // Get constructor and method information (step 5 and 7). Also determine if there is a class
     // initializer (step 6).
-    if (computeSVUID) {
+    if (computeSvuid) {
       if (CLINIT.equals(name)) {
         hasStaticInitializer = true;
       }
@@ -245,11 +246,11 @@ public class SerialVersionUIDAdder extends ClassVisitor {
       final Object value) {
     // Get the class field information for step 4 of the algorithm. Also determine if the class
     // already has a SVUID.
-    if (computeSVUID) {
+    if (computeSvuid) {
       if ("serialVersionUID".equals(name)) {
         // Since the class already has SVUID, we won't be computing it.
-        computeSVUID = false;
-        hasSVUID = true;
+        computeSvuid = false;
+        hasSvuid = true;
       }
       // Collect the non private fields. Only the ACC_PUBLIC, ACC_PRIVATE, ACC_PROTECTED,
       // ACC_STATIC, ACC_FINAL, ACC_VOLATILE, and ACC_TRANSIENT flags are used when computing
@@ -291,7 +292,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
   @Override
   public void visitEnd() {
     // Add the SVUID field to the class if it doesn't have one.
-    if (computeSVUID && !hasSVUID) {
+    if (computeSvuid && !hasSvuid) {
       try {
         addSVUID(computeSVUID());
       } catch (IOException e) {
@@ -312,8 +313,9 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    *
    * @return true if the class already has a SVUID field.
    */
+  // DontCheck(AbbreviationAsWordInName): can't be renamed (for backward binary compatibility).
   public boolean hasSVUID() {
-    return hasSVUID;
+    return hasSvuid;
   }
 
   /**
@@ -321,6 +323,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    *
    * @param svuid the serialVersionUID field value.
    */
+  // DontCheck(AbbreviationAsWordInName): can't be renamed (for backward binary compatibility).
   protected void addSVUID(final long svuid) {
     FieldVisitor fieldVisitor =
         super.visitField(
@@ -336,6 +339,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    * @return the serial version UID.
    * @throws IOException if an I/O error occurs.
    */
+  // DontCheck(AbbreviationAsWordInName): can't be renamed (for backward binary compatibility).
   protected long computeSVUID() throws IOException {
     ByteArrayOutputStream byteArrayOutputStream = null;
     DataOutputStream dataOutputStream = null;
@@ -425,11 +429,12 @@ public class SerialVersionUIDAdder extends ClassVisitor {
    * @param value the value whose SHA message digest must be computed.
    * @return the SHA-1 message digest of the given value.
    */
+  // DontCheck(AbbreviationAsWordInName): can't be renamed (for backward binary compatibility).
   protected byte[] computeSHAdigest(final byte[] value) {
     try {
       return MessageDigest.getInstance("SHA").digest(value);
-    } catch (Exception e) {
-      throw new UnsupportedOperationException(e.toString());
+    } catch (NoSuchAlgorithmException e) {
+      throw new UnsupportedOperationException(e);
     }
   }
 
@@ -446,8 +451,7 @@ public class SerialVersionUIDAdder extends ClassVisitor {
       final DataOutput dataOutputStream,
       final boolean dotted)
       throws IOException {
-    int size = itemCollection.size();
-    Item[] items = itemCollection.toArray(new Item[size]);
+    Item[] items = itemCollection.toArray(new Item[0]);
     Arrays.sort(
         items,
         new Comparator<Item>() {
