@@ -37,9 +37,12 @@ import org.junit.jupiter.params.provider.ValueSource;
 import org.objectweb.asm.ClassReader;
 import org.objectweb.asm.ClassVisitor;
 import org.objectweb.asm.ClassWriter;
+import org.objectweb.asm.ConstantDynamic;
+import org.objectweb.asm.Handle;
 import org.objectweb.asm.Label;
 import org.objectweb.asm.MethodVisitor;
 import org.objectweb.asm.Opcodes;
+import org.objectweb.asm.Type;
 import org.objectweb.asm.test.AsmTest;
 
 /**
@@ -179,7 +182,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitTypeInsn(Opcodes.NEW, "C");
           methodGenerator.visitInsn(Opcodes.DUP);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitVarInsn(Opcodes.ASTORE, 1);
           methodGenerator.visitVarInsn(Opcodes.ALOAD, 0);
           methodGenerator.visitJumpInsn(Opcodes.GOTO, label1);
@@ -208,7 +211,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitInsn(Opcodes.DUP_X1);
           methodGenerator.visitInsn(Opcodes.POP);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -228,7 +231,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitInsn(Opcodes.DUP_X2);
           methodGenerator.visitInsn(Opcodes.POP2);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -247,7 +250,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitInsn(Opcodes.DUP2);
           methodGenerator.visitInsn(Opcodes.POP2);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -268,7 +271,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitInsn(Opcodes.POP2);
           methodGenerator.visitInsn(Opcodes.POP);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -289,7 +292,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitInsn(Opcodes.POP2);
           methodGenerator.visitInsn(Opcodes.POP2);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -311,7 +314,7 @@ public class AdviceAdapterTest extends AsmTest {
           methodGenerator.visitLdcInsn(123L);
           methodGenerator.visitInsn(Opcodes.LASTORE);
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
-          // No method enter here because the above call does not initializes 'this'.
+          // No method enter here because the above call does not initialize 'this'.
           methodGenerator.visitMethodInsn(Opcodes.INVOKESPECIAL, "C", "<init>", "()V", false);
           methodGenerator.expectMethodEnter();
           methodGenerator.expectMethodExit();
@@ -371,6 +374,35 @@ public class AdviceAdapterTest extends AsmTest {
         () -> generateClass(constructorGenerator, /* expectedClass= */ false));
   }
 
+  @Test
+  public void testOnMethodEnterWithMixedVisitors() {
+    AdviceAdapter adviceAdapter =
+        new AdviceAdapter(
+            Opcodes.ASM7, new MethodVisitor(Opcodes.ASM7) {}, Opcodes.ACC_PUBLIC, "<init>", "()V") {
+          @Override
+          protected void onMethodEnter() {
+            Label label = new Label();
+            visitLabel(label);
+            // Generate ICONST_1 with the delegate visitor. The advice adapter does not 'see' this
+            // and therefore cannot update its stack state, if it were doing so.
+            mv.visitInsn(ICONST_1);
+            // Generate IFEQ with the advice adapter itself. If the stack was updated here, it would
+            // pop from an empty stack because the previous ICONST_1 was not simulated.
+            visitJumpInsn(IFEQ, label);
+          }
+
+          @Override
+          protected void onMethodExit(final int opcode) {}
+        };
+    adviceAdapter.visitCode();
+    adviceAdapter.visitVarInsn(Opcodes.ALOAD, 0);
+    adviceAdapter.visitMethodInsn(
+        Opcodes.INVOKESPECIAL, "java/lang/Object", "<init>", "()V", false);
+    adviceAdapter.visitInsn(Opcodes.RETURN);
+    adviceAdapter.visitMaxs(0, 0);
+    adviceAdapter.visitEnd();
+  }
+
   private static void testCase(final Consumer<MethodGenerator> testCaseGenerator) {
     byte[] actualClass = generateClass(testCaseGenerator, /* expectedClass= */ false);
     byte[] expectedClass = generateClass(testCaseGenerator, /* expectedClass= */ true);
@@ -385,6 +417,16 @@ public class AdviceAdapterTest extends AsmTest {
 
     classWriter.visitField(Opcodes.ACC_STATIC, "f", "[[I", null, null);
 
+    MethodVisitor defaultConstructorVisitor =
+        classWriter.visitMethod(Opcodes.ACC_PUBLIC, "<init>", "()V", null, null);
+    defaultConstructorVisitor.visitCode();
+    defaultConstructorVisitor.visitVarInsn(Opcodes.ALOAD, 0);
+    defaultConstructorVisitor.visitMethodInsn(
+        Opcodes.INVOKESPECIAL, "java/lang/Object", "<init>", "()V", false);
+    defaultConstructorVisitor.visitInsn(Opcodes.RETURN);
+    defaultConstructorVisitor.visitMaxs(0, 0);
+    defaultConstructorVisitor.visitEnd();
+
     String descriptor = "(I)V";
     MethodVisitor methodVisitor =
         classWriter.visitMethod(Opcodes.ACC_PUBLIC, "<init>", descriptor, null, null);
@@ -395,7 +437,29 @@ public class AdviceAdapterTest extends AsmTest {
       methodGenerator =
           new MethodGenerator(
               new AdviceAdapter(
-                  Opcodes.ASM6, methodVisitor, Opcodes.ACC_PUBLIC, "<init>", descriptor) {
+                  Opcodes.ASM7, methodVisitor, Opcodes.ACC_PUBLIC, "<init>", descriptor) {
+
+                @Override
+                public void visitLdcInsn(final Object value) {
+                  if (value instanceof Boolean
+                      || value instanceof Byte
+                      || value instanceof Short
+                      || value instanceof Character
+                      || value instanceof Integer
+                      || value instanceof Long
+                      || value instanceof Double
+                      || value instanceof Float
+                      || value instanceof String
+                      || value instanceof Type
+                      || value instanceof Handle
+                      || value instanceof ConstantDynamic) {
+                    super.visitLdcInsn(value);
+                  } else {
+                    // If this happens, add support for the new type in
+                    // AdviceAdapter.visitLdcInsn(), if needed.
+                    throw new IllegalArgumentException("Unsupported type of value: " + value);
+                  }
+                }
 
                 @Override
                 protected void onMethodEnter() {
@@ -418,28 +482,6 @@ public class AdviceAdapterTest extends AsmTest {
     return classWriter.toByteArray();
   }
 
-  private static class MethodGenerator extends MethodVisitor {
-
-    private final boolean expectedClass;
-
-    MethodGenerator(final MethodVisitor methodVisitor, final boolean expectedClass) {
-      super(Opcodes.ASM6, methodVisitor);
-      this.expectedClass = expectedClass;
-    }
-
-    public void expectMethodEnter() {
-      if (expectedClass) {
-        generateAdvice(this, /* enter= */ true);
-      }
-    }
-
-    public void expectMethodExit() {
-      if (expectedClass) {
-        generateAdvice(this, /* enter= */ false);
-      }
-    }
-  }
-
   private static void generateAdvice(final MethodVisitor methodVisitor, final boolean enter) {
     methodVisitor.visitFieldInsn(
         Opcodes.GETSTATIC, "java/lang/System", "err", "Ljava/io/PrintStream;");
@@ -477,6 +519,28 @@ public class AdviceAdapterTest extends AsmTest {
     assertThatClass(actualClassWriter.toByteArray()).isEqualTo(expectedClassWriter.toByteArray());
   }
 
+  private static class MethodGenerator extends MethodVisitor {
+
+    private final boolean expectedClass;
+
+    MethodGenerator(final MethodVisitor methodVisitor, final boolean expectedClass) {
+      super(Opcodes.ASM7, methodVisitor);
+      this.expectedClass = expectedClass;
+    }
+
+    public void expectMethodEnter() {
+      if (expectedClass) {
+        generateAdvice(this, /* enter= */ true);
+      }
+    }
+
+    public void expectMethodExit() {
+      if (expectedClass) {
+        generateAdvice(this, /* enter= */ false);
+      }
+    }
+  }
+
   private static class ReferenceClassAdapter extends ClassVisitor {
 
     ReferenceClassAdapter(final int api, final ClassVisitor classVisitor) {
