@@ -130,8 +130,7 @@ public abstract class AsmTest {
     JDK9_MODULE("jdk9.module-info"),
     JDK11_ALL_INSTRUCTIONS("jdk11.AllInstructions"),
     JDK11_ALL_STRUCTURES("jdk11.AllStructures"),
-    JDK11_ALL_STRUCTURES_NESTED("jdk11.AllStructures$Nested"),
-    JDK11_LAMBDA_CONDY("jdk11.LambdaCondy");
+    JDK11_ALL_STRUCTURES_NESTED("jdk11.AllStructures$Nested");
 
     private final String name;
 
@@ -139,12 +138,20 @@ public abstract class AsmTest {
       this.name = name;
     }
 
-    /** @return the fully qualified name of this class. */
+    /**
+     * Returns the fully qualified name of this class.
+     *
+     * @return the fully qualified name of this class.
+     */
     public String getName() {
       return name;
     }
 
-    /** @return the internal name of this class. */
+    /**
+     * Returns the internal name of this class.
+     *
+     * @return the internal name of this class.
+     */
     public String getInternalName() {
       return name.endsWith(MODULE_INFO) ? MODULE_INFO : name.replace('.', '/');
     }
@@ -184,7 +191,11 @@ public abstract class AsmTest {
       return false;
     }
 
-    /** @return the content of this class. */
+    /**
+     * Returns the content of this class.
+     *
+     * @return the content of this class.
+     */
     public byte[] getBytes() {
       return AsmTest.getBytes(name);
     }
@@ -220,7 +231,11 @@ public abstract class AsmTest {
       this.name = name;
     }
 
-    /** @return the content of this class. */
+    /**
+     * Returns the content of this class.
+     *
+     * @return the content of this class.
+     */
     public byte[] getBytes() {
       return AsmTest.getBytes(name);
     }
@@ -236,7 +251,7 @@ public abstract class AsmTest {
     ASM4("ASM4", 4 << 16),
     ASM5("ASM5", 5 << 16),
     ASM6("ASM6", 6 << 16),
-    ASM7("ASM7", 1 << 24 | 7 << 16);
+    ASM7("ASM7", 7 << 16);
 
     private final String name;
     private final int value;
@@ -268,7 +283,7 @@ public abstract class AsmTest {
 
   /**
    * Builds a list of test arguments for a parameterized test. Parameterized test cases annotated
-   * with <tt>@MethodSource("allClassesAndAllApis")</tt> will be executed on all the possible
+   * with {@code @MethodSource("allClassesAndAllApis")} will be executed on all the possible
    * (precompiledClass, api) pairs.
    *
    * @return all the possible (precompiledClass, api) pairs, for all the precompiled classes and all
@@ -280,7 +295,7 @@ public abstract class AsmTest {
 
   /**
    * Builds a list of test arguments for a parameterized test. Parameterized test cases annotated
-   * with <tt>@MethodSource("allClassesAndLatestApi")</tt> will be executed on all the precompiled
+   * with {@code @MethodSource("allClassesAndLatestApi")} will be executed on all the precompiled
    * classes, with the latest api.
    *
    * @return all the possible (precompiledClass, ASM7) pairs, for all the precompiled classes.
@@ -312,48 +327,6 @@ public abstract class AsmTest {
     return new ClassSubject(classFile);
   }
 
-  /** Helper to make assertions about a class. */
-  public static class ClassSubject {
-    /** The content of the class to be tested. */
-    private final byte[] classFile;
-
-    ClassSubject(final byte[] classFile) {
-      this.classFile = classFile;
-    }
-
-    /**
-     * Asserts that a dump of the subject class into a string representation contains the given
-     * string.
-     *
-     * @param expectedString a string which should be contained in a dump of the subject class.
-     */
-    public void contains(final String expectedString) {
-      try {
-        String dump = new ClassDump(classFile).toString();
-        assertTrue(dump.contains(expectedString));
-      } catch (IOException | IllegalArgumentException e) {
-        fail("Class can't be dumped", e);
-      }
-    }
-
-    /**
-     * Asserts that the subject class is equal to the given class, modulo some low level bytecode
-     * representation details (e.g. the order of the constants in the constant pool, the order of
-     * attributes and annotations, and low level details such as ldc vs ldc_w instructions).
-     *
-     * @param expectedClassFile a class file content which should be equal to the subject class.
-     */
-    public void isEqualTo(final byte[] expectedClassFile) {
-      try {
-        String dump = new ClassDump(classFile).toString();
-        String expectedDump = new ClassDump(expectedClassFile).toString();
-        assertEquals(expectedDump, dump);
-      } catch (IOException | IllegalArgumentException e) {
-        fail("Class can't be dumped", e);
-      }
-    }
-  }
-
   /**
    * Loads the given class in a new class loader. Also tries to instantiate the loaded class (if it
    * is not an abstract or enum class, or a module-info class), in order to check that it passes the
@@ -401,7 +374,7 @@ public abstract class AsmTest {
           arguments.add(Array.get(Array.newInstance(parameterType, 1), 0));
         }
         constructor.setAccessible(true);
-        constructor.newInstance(arguments.toArray(new Object[arguments.size()]));
+        constructor.newInstance(arguments.toArray(new Object[0]));
       }
     } catch (ClassNotFoundException e) {
       // Should never happen given the ByteClassLoader implementation.
@@ -413,11 +386,72 @@ public abstract class AsmTest {
       fail("Can't instantiate class " + className, e);
     } catch (InvocationTargetException e) {
       // If an exception occurs in the invoked constructor, it means the class was successfully
-      // verified first.
+      // verified first. Still, we fail the test to be on the safe side.
+      fail("An exception occurred in the constructor of " + className, e);
     }
     return byteClassLoader.classLoaded();
   }
 
+  private static byte[] getBytes(final String name) {
+    String resourceName = name.replace('.', '/') + ".class";
+    try (InputStream inputStream = ClassLoader.getSystemResourceAsStream(resourceName)) {
+      assertNotNull(inputStream, "Class not found " + name);
+      ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+      byte[] data = new byte[INPUT_STREAM_DATA_CHUNK_SIZE];
+      int bytesRead;
+      while ((bytesRead = inputStream.read(data, 0, data.length)) != -1) {
+        outputStream.write(data, 0, bytesRead);
+      }
+      outputStream.flush();
+      return outputStream.toByteArray();
+    } catch (IOException e) {
+      fail("Can't read " + name, e);
+      return new byte[0];
+    }
+  }
+
+  /** Helper to make assertions about a class. */
+  public static class ClassSubject {
+    /** The content of the class to be tested. */
+    private final byte[] classFile;
+
+    ClassSubject(final byte[] classFile) {
+      this.classFile = classFile;
+    }
+
+    /**
+     * Asserts that a dump of the subject class into a string representation contains the given
+     * string.
+     *
+     * @param expectedString a string which should be contained in a dump of the subject class.
+     */
+    public void contains(final String expectedString) {
+      try {
+        String dump = new ClassDump(classFile).toString();
+        assertTrue(dump.contains(expectedString));
+      } catch (IOException | IllegalArgumentException e) {
+        fail("Class can't be dumped", e);
+      }
+    }
+
+    /**
+     * Asserts that the subject class is equal to the given class, modulo some low level bytecode
+     * representation details (e.g. the order of the constants in the constant pool, the order of
+     * attributes and annotations, and low level details such as ldc vs ldc_w instructions).
+     *
+     * @param expectedClassFile a class file content which should be equal to the subject class.
+     */
+    public void isEqualTo(final byte[] expectedClassFile) {
+      try {
+        String dump = new ClassDump(classFile).toString();
+        String expectedDump = new ClassDump(expectedClassFile).toString();
+        assertEquals(expectedDump, dump);
+      } catch (IOException | IllegalArgumentException e) {
+        fail("Class can't be dumped", e);
+      }
+    }
+  }
+
   /** A simple ClassLoader to test that a class can be loaded in the JVM. */
   private static class ByteClassLoader extends ClassLoader {
     private final String className;
@@ -444,22 +478,4 @@ public abstract class AsmTest {
       }
     }
   }
-
-  private static byte[] getBytes(final String name) {
-    String resourceName = name.replace('.', '/') + ".class";
-    try (InputStream inputStream = ClassLoader.getSystemResourceAsStream(resourceName)) {
-      assertNotNull(inputStream, "Class not found " + name);
-      ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
-      byte[] data = new byte[INPUT_STREAM_DATA_CHUNK_SIZE];
-      int bytesRead;
-      while ((bytesRead = inputStream.read(data, 0, data.length)) != -1) {
-        outputStream.write(data, 0, bytesRead);
-      }
-      outputStream.flush();
-      return outputStream.toByteArray();
-    } catch (IOException e) {
-      fail("Can't read " + name, e);
-      return new byte[0];
-    }
-  }
 }
