@@ -28,6 +28,7 @@
 package org.objectweb.asm.tree;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -80,10 +81,9 @@ public class ClassNodeTest extends AsmTest implements Opcodes {
     assertEquals("1.0", moduleNode.version);
 
     ModuleNode otherModuleNode =
-        new ModuleNode(
-            Opcodes.ASM7_EXPERIMENTAL, "otherModule", 456, "2.0", null, null, null, null, null);
+        new ModuleNode(Opcodes.ASM7, "otherModule", 456, "2.0", null, null, null, null, null);
     moduleNode.accept(
-        new ClassVisitor(Opcodes.ASM7_EXPERIMENTAL) {
+        new ClassVisitor(Opcodes.ASM7) {
           @Override
           public ModuleVisitor visitModule(
               final String name, final int access, final String version) {
@@ -150,7 +150,7 @@ public class ClassNodeTest extends AsmTest implements Opcodes {
     assertEquals("value", annotationNode.values.get(17));
 
     annotationNode.accept(
-        new AnnotationVisitor(Opcodes.ASM7_EXPERIMENTAL) {
+        new AnnotationVisitor(Opcodes.ASM7) {
 
           @Override
           public AnnotationVisitor visitAnnotation(final String name, final String descriptor) {
@@ -241,12 +241,12 @@ public class ClassNodeTest extends AsmTest implements Opcodes {
     MethodInsnNode methodInsnNode = new MethodInsnNode(INVOKESTATIC, "owner", "name", "()I");
     assertEquals(AbstractInsnNode.METHOD_INSN, methodInsnNode.getType());
     assertEquals(INVOKESTATIC, methodInsnNode.getOpcode());
-    assertEquals(false, methodInsnNode.itf);
+    assertFalse(methodInsnNode.itf);
 
     methodInsnNode = new MethodInsnNode(INVOKEINTERFACE, "owner", "name", "()I");
     assertEquals(AbstractInsnNode.METHOD_INSN, methodInsnNode.getType());
     assertEquals(INVOKEINTERFACE, methodInsnNode.getOpcode());
-    assertEquals(true, methodInsnNode.itf);
+    assertTrue(methodInsnNode.itf);
   }
 
   @Test
@@ -257,7 +257,7 @@ public class ClassNodeTest extends AsmTest implements Opcodes {
     assertEquals("owner", methodInsnNode.owner);
     assertEquals("name", methodInsnNode.name);
     assertEquals("()I", methodInsnNode.desc);
-    assertEquals(false, methodInsnNode.itf);
+    assertFalse(methodInsnNode.itf);
 
     methodInsnNode.setOpcode(INVOKESPECIAL);
     assertEquals(INVOKESPECIAL, methodInsnNode.getOpcode());
@@ -501,10 +501,10 @@ public class ClassNodeTest extends AsmTest implements Opcodes {
     }
 
     @Override
-    public void visitNestHostExperimental(final String nestHost) {}
+    public void visitNestHost(final String nestHost) {}
 
     @Override
-    public void visitNestMemberExperimental(final String nestMember) {}
+    public void visitNestMember(final String nestMember) {}
 
     @Override
     public void visitAttribute(final Attribute attribute) {}
