@@ -54,8 +54,6 @@ public class InsnListTest {
 
   private InsnList list2;
 
-  private InsnList list3Unchecked;
-
   private InsnNode insn1;
 
   private InsnNode insn2;
@@ -64,7 +62,6 @@ public class InsnListTest {
   public void setUp() throws Exception {
     list1 = new CheckedInsnList();
     list2 = new CheckedInsnList();
-    list3Unchecked = new InsnList();
     insn1 = new InsnNode(0);
     insn2 = new InsnNode(0);
     list2.add(insn1);
@@ -100,13 +97,11 @@ public class InsnListTest {
 
   @Test
   public void testContains() {
-    assertEquals(false, list1.contains(new InsnNode(0)));
+    assertFalse(list1.contains(new InsnNode(0)));
   }
 
   @Test
   public void testIterator() {
-    InsnNode insn = new InsnNode(0);
-
     // Iterate.
     ListIterator<AbstractInsnNode> iterator = list2.iterator();
     assertTrue(iterator.hasNext());
@@ -120,6 +115,7 @@ public class InsnListTest {
     assertEquals(insn1, iterator.previous());
     assertFalse(iterator.hasPrevious());
 
+    InsnNode insn = new InsnNode(0);
     list2.add(insn);
 
     // Remove.
@@ -325,16 +321,6 @@ public class InsnListTest {
     assertEquals(insn, list1.get(1));
   }
 
-  @Test
-  public void testSetNodeAssociatedWithAnotherList() {
-    InsnNode insnNode = new InsnNode(0);
-    list3Unchecked.add(insnNode);
-    list3Unchecked.set(insnNode, insn1);
-    ListIterator<AbstractInsnNode> iterator = list3Unchecked.iterator();
-    iterator.next();
-    assertFalse(iterator.hasNext());
-  }
-
   @Test
   public void testInvalidAdd() {
     assertThrows(IllegalArgumentException.class, () -> list1.add(insn1));
@@ -348,7 +334,7 @@ public class InsnListTest {
     assertEquals(insn, list1.getFirst());
     assertEquals(insn, list1.getLast());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
+    assertTrue(list1.contains(insn));
     assertEquals(0, list1.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn}, list1.toArray());
     assertEquals(null, insn.getPrevious());
@@ -364,15 +350,7 @@ public class InsnListTest {
     assertEquals(insn, list1.getLast());
     assertEquals(1, list1.indexOf(insn));
     assertEquals(insn, list1.get(1));
-    assertEquals(true, list1.contains(insn));
-  }
-
-  @Test
-  public void testAddNodeAssociatedWithAnotherList() {
-    list3Unchecked.add(insn1);
-    ListIterator<AbstractInsnNode> iterator = list3Unchecked.iterator();
-    iterator.next();
-    assertFalse(iterator.hasNext());
+    assertTrue(list1.contains(insn));
   }
 
   @Test
@@ -396,8 +374,8 @@ public class InsnListTest {
     assertEquals(insn1, list1.getFirst());
     assertEquals(insn2, list1.getLast());
     assertEquals(insn1, list1.get(0));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn1));
     assertEquals(1, list1.indexOf(insn2));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn1, insn2}, list1.toArray());
@@ -412,9 +390,9 @@ public class InsnListTest {
     assertEquals(insn, list1.getFirst());
     assertEquals(insn2, list1.getLast());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn));
     assertEquals(1, list1.indexOf(insn1));
     assertEquals(2, list1.indexOf(insn2));
@@ -434,7 +412,7 @@ public class InsnListTest {
     assertEquals(insn, list1.getFirst());
     assertEquals(insn, list1.getLast());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
+    assertTrue(list1.contains(insn));
     assertEquals(0, list1.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn}, list1.toArray());
   }
@@ -447,7 +425,7 @@ public class InsnListTest {
     assertEquals(2, list1.size());
     assertEquals(insn, list1.getFirst());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
+    assertTrue(list1.contains(insn));
     assertEquals(0, list1.indexOf(insn));
   }
 
@@ -472,8 +450,8 @@ public class InsnListTest {
     assertEquals(insn1, list1.getFirst());
     assertEquals(insn2, list1.getLast());
     assertEquals(insn1, list1.get(0));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn1));
     assertEquals(1, list1.indexOf(insn2));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn1, insn2}, list1.toArray());
@@ -488,9 +466,9 @@ public class InsnListTest {
     assertEquals(insn1, list1.getFirst());
     assertEquals(insn, list1.getLast());
     assertEquals(insn1, list1.get(0));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn1));
     assertEquals(1, list1.indexOf(insn2));
     assertEquals(2, list1.indexOf(insn));
@@ -511,7 +489,7 @@ public class InsnListTest {
     assertEquals(insn1, list2.getFirst());
     assertEquals(insn2, list2.getLast());
     assertEquals(insn1, list2.get(0));
-    assertEquals(true, list2.contains(insn));
+    assertTrue(list2.contains(insn));
     assertEquals(1, list2.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn1, insn, insn2}, list2.toArray());
   }
@@ -524,7 +502,7 @@ public class InsnListTest {
     assertEquals(insn1, list2.getFirst());
     assertEquals(insn, list2.getLast());
     assertEquals(insn1, list2.get(0));
-    assertEquals(true, list2.contains(insn));
+    assertTrue(list2.contains(insn));
     assertEquals(2, list2.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn1, insn2, insn}, list2.toArray());
   }
@@ -537,7 +515,7 @@ public class InsnListTest {
     assertEquals(insn1, list2.getFirst());
     assertEquals(insn2, list2.getLast());
     assertEquals(insn, list2.get(1));
-    assertEquals(true, list2.contains(insn));
+    assertTrue(list2.contains(insn));
     assertEquals(1, list2.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn1, insn, insn2}, list2.toArray());
   }
@@ -550,7 +528,7 @@ public class InsnListTest {
     assertEquals(insn, list2.getFirst());
     assertEquals(insn2, list2.getLast());
     assertEquals(insn, list2.get(0));
-    assertEquals(true, list2.contains(insn));
+    assertTrue(list2.contains(insn));
     assertEquals(0, list2.indexOf(insn));
     assertEqualInsnArrays(new AbstractInsnNode[] {insn, insn1, insn2}, list2.toArray());
   }
@@ -587,9 +565,9 @@ public class InsnListTest {
     assertEquals(4, list1.size());
     assertEquals(insn, list1.getFirst());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn));
     assertEquals(1, list1.indexOf(insn1));
     assertEquals(2, list1.indexOf(insn2));
@@ -604,9 +582,9 @@ public class InsnListTest {
     assertEquals(insn, list1.getFirst());
     assertEquals(insn2, list1.getLast());
     assertEquals(insn, list1.get(0));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(0, list1.indexOf(insn));
     assertEquals(1, list1.indexOf(insn1));
     assertEquals(2, list1.indexOf(insn2));
@@ -639,9 +617,9 @@ public class InsnListTest {
     assertEquals(4, list1.size());
     assertEquals(insn1, list1.get(1));
     assertEquals(insn2, list1.get(2));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(3, list1.indexOf(insn));
     assertEquals(1, list1.indexOf(insn1));
     assertEquals(2, list1.indexOf(insn2));
@@ -656,9 +634,9 @@ public class InsnListTest {
     assertEquals(insn1, list1.getFirst());
     assertEquals(insn, list1.getLast());
     assertEquals(insn1, list1.get(0));
-    assertEquals(true, list1.contains(insn));
-    assertEquals(true, list1.contains(insn1));
-    assertEquals(true, list1.contains(insn2));
+    assertTrue(list1.contains(insn));
+    assertTrue(list1.contains(insn1));
+    assertTrue(list1.contains(insn2));
     assertEquals(2, list1.indexOf(insn));
     assertEquals(0, list1.indexOf(insn1));
     assertEquals(1, list1.indexOf(insn2));
@@ -678,7 +656,7 @@ public class InsnListTest {
     assertEquals(0, list1.size());
     assertEquals(null, list1.getFirst());
     assertEquals(null, list1.getLast());
-    assertEquals(false, list1.contains(insn));
+    assertFalse(list1.contains(insn));
     assertEqualInsnArrays(new AbstractInsnNode[0], list1.toArray());
     assertEquals(null, insn.getPrevious());
     assertEquals(null, insn.getNext());
@@ -690,7 +668,7 @@ public class InsnListTest {
     list1.add(insn);
     list1.add(new InsnNode(0));
     list1.remove(insn);
-    assertEquals(false, list1.contains(insn));
+    assertFalse(list1.contains(insn));
     assertEquals(null, insn.getPrevious());
     assertEquals(null, insn.getNext());
   }
@@ -702,7 +680,7 @@ public class InsnListTest {
     list1.add(insn);
     list1.add(new InsnNode(0));
     list1.remove(insn);
-    assertEquals(false, list1.contains(insn));
+    assertFalse(list1.contains(insn));
     assertEquals(null, insn.getPrevious());
     assertEquals(null, insn.getNext());
   }
@@ -713,7 +691,7 @@ public class InsnListTest {
     list1.add(new InsnNode(0));
     list1.add(insn);
     list1.remove(insn);
-    assertEquals(false, list1.contains(insn));
+    assertFalse(list1.contains(insn));
     assertEquals(null, insn.getPrevious());
     assertEquals(null, insn.getNext());
   }
@@ -728,7 +706,7 @@ public class InsnListTest {
     assertEquals(0, list1.size());
     assertEquals(null, list1.getFirst());
     assertEquals(null, list1.getLast());
-    assertEquals(false, list1.contains(insn));
+    assertFalse(list1.contains(insn));
     assertEqualInsnArrays(new AbstractInsnNode[0], list1.toArray());
     assertEquals(null, insn.getPrevious());
     assertEquals(null, insn.getNext());
@@ -741,7 +719,7 @@ public class InsnListTest {
 
     final InsnList insnList = new InsnList();
     list1.accept(
-        new MethodVisitor(Opcodes.ASM7_EXPERIMENTAL) {
+        new MethodVisitor(Opcodes.ASM7) {
           @Override
           public void visitInsn(final int opcode) {
             insnList.add(new InsnNode(opcode));
