@@ -167,9 +167,11 @@ public class CheckMethodAdapterTest extends AsmTest implements Opcodes {
         RuntimeException.class,
         () -> checkMethodAdapter.visitFrame(F_FULL, 1, new Object[] {"LC;"}, 0, null));
     checkMethodAdapter.visitInsn(NOP);
+    Integer invalidFrameValue =
+        new Integer(0); // NOPMD(IntegerInstantiation): needed to build an invalid value.
     assertThrows(
         RuntimeException.class,
-        () -> checkMethodAdapter.visitFrame(F_FULL, 1, new Object[] {new Integer(0)}, 0, null));
+        () -> checkMethodAdapter.visitFrame(F_FULL, 1, new Object[] {invalidFrameValue}, 0, null));
     checkMethodAdapter.visitInsn(NOP);
     assertThrows(
         RuntimeException.class,
@@ -253,7 +255,7 @@ public class CheckMethodAdapterTest extends AsmTest implements Opcodes {
     ClassReader classReader = new ClassReader("java.lang.Object");
     ClassWriter classWriter = new ClassWriter(classReader, ClassWriter.COMPUTE_MAXS);
     ClassVisitor classVisitor =
-        new ClassVisitor(Opcodes.ASM7_EXPERIMENTAL, classWriter) {
+        new ClassVisitor(Opcodes.ASM7, classWriter) {
           @Override
           public MethodVisitor visitMethod(
               final int access,
@@ -268,7 +270,7 @@ public class CheckMethodAdapterTest extends AsmTest implements Opcodes {
             }
             return new MethodVisitor(api, new CheckMethodAdapter(next)) {
 
-              private Label entryLabel = null;
+              private Label entryLabel;
 
               @Override
               public void visitLabel(final Label label) {
