@@ -28,6 +28,7 @@
 package org.objectweb.asm;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
@@ -102,13 +103,13 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     assertNotNull(interfaces);
   }
 
-  /** Tests {@link ClassReader(byte[])} and the basic ClassReader accessors. */
+  /** Tests {@link ClassReader#ClassReader(byte[])} and the basic ClassReader accessors. */
   @ParameterizedTest
   @MethodSource(ALL_CLASSES_AND_ALL_APIS)
   public void testByteArrayConstructorAndAccessors(
       final PrecompiledClass classParameter, final Api apiParameter) {
     ClassReader classReader = new ClassReader(classParameter.getBytes());
-    assertTrue(classReader.getAccess() != 0);
+    assertNotEquals(0, classReader.getAccess());
     assertEquals(classParameter.getInternalName(), classReader.getClassName());
     if (classParameter.getInternalName().equals("module-info")) {
       assertNull(classReader.getSuperName());
@@ -118,7 +119,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     assertNotNull(classReader.getInterfaces());
   }
 
-  /** Tests {@link ClassReader(byte[],int,int)} and the basic ClassReader accessors. */
+  /** Tests {@link ClassReader#ClassReader(byte[],int,int)} and the basic ClassReader accessors. */
   @ParameterizedTest
   @MethodSource(ALL_CLASSES_AND_LATEST_API)
   public void testByteArrayConstructorWithOffsetAndAccessors(
@@ -127,7 +128,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     byte[] byteBuffer = new byte[classFile.length + 1];
     System.arraycopy(classFile, 0, byteBuffer, 1, classFile.length);
     ClassReader classReader = new ClassReader(byteBuffer, 1, classFile.length);
-    assertTrue(classReader.getAccess() != 0);
+    assertNotEquals(0, classReader.getAccess());
     assertEquals(classParameter.getInternalName(), classReader.getClassName());
     if (classParameter.getInternalName().equals("module-info")) {
       assertNull(classReader.getSuperName());
@@ -152,13 +153,13 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
         0);
   }
 
-  /** Tests {@link ClassReader(String)} and the basic ClassReader accessors. */
+  /** Tests {@link ClassReader#ClassReader(String)} and the basic ClassReader accessors. */
   @ParameterizedTest
   @MethodSource(ALL_CLASSES_AND_ALL_APIS)
   public void testNameConstructorAndAccessors(
       final PrecompiledClass classParameter, final Api apiParameter) throws IOException {
     ClassReader classReader = new ClassReader(classParameter.getName());
-    assertTrue(classReader.getAccess() != 0);
+    assertNotEquals(0, classReader.getAccess());
     assertEquals(classParameter.getInternalName(), classReader.getClassName());
     if (classParameter.getInternalName().equals("module-info")) {
       assertNull(classReader.getSuperName());
@@ -168,7 +169,9 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     assertNotNull(classReader.getInterfaces());
   }
 
-  /** Tests {@link ClassReader(java.io.InputStream)} and the basic ClassReader accessors. */
+  /**
+   * Tests {@link ClassReader#ClassReader(java.io.InputStream)} and the basic ClassReader accessors.
+   */
   @ParameterizedTest
   @MethodSource(ALL_CLASSES_AND_ALL_APIS)
   public void testStreamConstructorAndAccessors(
@@ -177,7 +180,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
         new ClassReader(
             ClassLoader.getSystemResourceAsStream(
                 classParameter.getName().replace('.', '/') + ".class"));
-    assertTrue(classReader.getAccess() != 0);
+    assertNotEquals(0, classReader.getAccess());
     assertEquals(classParameter.getInternalName(), classReader.getClassName());
     if (classParameter.getInternalName().equals("module-info")) {
       assertNull(classReader.getSuperName());
@@ -187,7 +190,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     assertNotNull(classReader.getInterfaces());
   }
 
-  /** Tests {@link ClassReader(java.io.InputStream)} with an empty stream. */
+  /** Tests {@link ClassReader#ClassReader(java.io.InputStream)} with an empty stream. */
   @Test
   public void testStreamConstructorWithEmptyStream() throws IOException {
     InputStream inputStream =
@@ -223,7 +226,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     assertThat(() -> classReader.accept(classVisitor, 0))
         .succeedsOrThrows(RuntimeException.class)
         .when(
-            (hasNestHostOrMembers && apiParameter.value() < ASM7_EXPERIMENTAL)
+            (hasNestHostOrMembers && apiParameter.value() < ASM7)
                 || (hasModules && apiParameter.value() < ASM6)
                 || (hasTypeAnnotations && apiParameter.value() < ASM5));
   }
@@ -285,14 +288,13 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     ClassVisitor classVisitor = new EmptyClassVisitor(apiParameter.value());
     // jdk8.ArtificialStructures contains structures which require ASM5, but only inside the method
     // code. Here we skip the code, so this class can be read with ASM4. Likewise for
-    // jdk11.AllInstructions and jdk11.LambdaCondy.
+    // jdk11.AllInstructions.
     assertThat(() -> classReader.accept(classVisitor, ClassReader.SKIP_CODE))
         .succeedsOrThrows(RuntimeException.class)
         .when(
             classParameter.isMoreRecentThan(apiParameter)
                 && classParameter != PrecompiledClass.JDK8_ARTIFICIAL_STRUCTURES
-                && classParameter != PrecompiledClass.JDK11_ALL_INSTRUCTIONS
-                && classParameter != PrecompiledClass.JDK11_LAMBDA_CONDY);
+                && classParameter != PrecompiledClass.JDK11_ALL_INSTRUCTIONS);
   }
 
   /**
@@ -390,10 +392,10 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
           }
 
           @Override
-          public void visitNestHostExperimental(final String nestHost) {}
+          public void visitNestHost(final String nestHost) {}
 
           @Override
-          public void visitNestMemberExperimental(final String nestMember) {}
+          public void visitNestMember(final String nestMember) {}
         };
     classReader.accept(classVisitor, 0);
   }
@@ -403,7 +405,7 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
     final AtomicBoolean success = new AtomicBoolean(false);
     ClassReader classReader = new ClassReader(PrecompiledClass.JDK5_LOCAL_CLASS.getBytes());
     classReader.accept(
-        new ClassVisitor(Opcodes.ASM7_EXPERIMENTAL) {
+        new ClassVisitor(Opcodes.ASM7) {
           @Override
           public MethodVisitor visitMethod(
               final int access,
@@ -430,19 +432,18 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
 
   @Test
   public void testPreviewMinorVersion() {
-    ClassReader classReader = new ClassReader(PrecompiledClass.JDK11_LAMBDA_CONDY.getBytes());
+    ClassReader classReader = new ClassReader(PrecompiledClass.JDK11_ALL_INSTRUCTIONS.getBytes());
     classReader.accept(
-        new ClassVisitor(Opcodes.ASM7_EXPERIMENTAL) {
+        new ClassVisitor(Opcodes.ASM7) {
           @Override
           public void visit(
-              int version,
-              int access,
-              String name,
-              String signature,
-              String superName,
-              String[] interfaces) {
-            assertTrue(
-                (version & Opcodes.V_PREVIEW_EXPERIMENTAL) == Opcodes.V_PREVIEW_EXPERIMENTAL);
+              final int version,
+              final int access,
+              final String name,
+              final String signature,
+              final String superName,
+              final String[] interfaces) {
+            assertEquals(Opcodes.V_PREVIEW, version & Opcodes.V_PREVIEW);
           }
         },
         0);
@@ -462,11 +463,11 @@ public class ClassReaderTest extends AsmTest implements Opcodes {
           || invalidClass == InvalidClass.INVALID_BYTECODE_OFFSET) {
         assertThrows(
             ArrayIndexOutOfBoundsException.class,
-            () -> classReader.accept(new EmptyClassVisitor(ASM7_EXPERIMENTAL), 0));
+            () -> classReader.accept(new EmptyClassVisitor(ASM7), 0));
       } else {
         assertThrows(
             IllegalArgumentException.class,
-            () -> classReader.accept(new EmptyClassVisitor(ASM7_EXPERIMENTAL), 0));
+            () -> classReader.accept(new EmptyClassVisitor(ASM7), 0));
       }
     }
   }
