@@ -48,11 +48,31 @@ import org.junit.jupiter.params.provider.ValueSource;
  */
 public class ClassWriterComputeMaxsTest {
 
-  private ClassWriter classWriter;
+  // Some local variable numbers used in tests.
+  private static final int LOCAL1 = 1;
+  private static final int LOCAL2 = 2;
+  private static final int LOCAL3 = 3;
+  private static final int LOCAL4 = 4;
+  private static final int LOCAL5 = 5;
 
+  private ClassWriter classWriter;
   private MethodVisitor methodVisitor;
 
-  private Label start;
+  // Labels used to generate test cases.
+  private final Label start = new Label();
+  private final Label label0 = new Label();
+  private final Label label1 = new Label();
+  private final Label label2 = new Label();
+  private final Label label3 = new Label();
+  private final Label label4 = new Label();
+  private final Label label5 = new Label();
+  private final Label label6 = new Label();
+  private final Label label7 = new Label();
+  private final Label label8 = new Label();
+  private final Label label9 = new Label();
+  private final Label label10 = new Label();
+  private final Label label11 = new Label();
+  private final Label label12 = new Label();
 
   @BeforeEach
   public void setUp() throws Exception {
@@ -72,83 +92,82 @@ public class ClassWriterComputeMaxsTest {
     methodVisitor.visitEnd();
     methodVisitor = classWriter.visitMethod(Opcodes.ACC_PUBLIC, "m", "()V", null, null);
     methodVisitor.visitCode();
-    start = new Label();
-    LABEL(start);
+    label(start);
   }
 
-  private void NOP() {
+  private void nop() {
     methodVisitor.visitInsn(Opcodes.NOP);
   }
 
-  private void PUSH() {
+  private void push() {
     methodVisitor.visitInsn(Opcodes.ICONST_0);
   }
 
-  private void POP() {
+  private void pop() {
     methodVisitor.visitInsn(Opcodes.POP);
   }
 
-  private void ICONST_0() {
+  private void iconst_0() {
     methodVisitor.visitInsn(Opcodes.ICONST_0);
   }
 
-  private void ISTORE(final int var) {
+  private void istore(final int var) {
     methodVisitor.visitVarInsn(Opcodes.ISTORE, var);
   }
 
-  private void ALOAD(final int var) {
+  private void aload(final int var) {
     methodVisitor.visitVarInsn(Opcodes.ALOAD, var);
   }
 
-  private void ILOAD(final int var) {
+  private void iload(final int var) {
     methodVisitor.visitVarInsn(Opcodes.ILOAD, var);
   }
 
-  private void ASTORE(final int var) {
+  private void astore(final int var) {
     methodVisitor.visitVarInsn(Opcodes.ASTORE, var);
   }
 
-  private void RET(final int var) {
+  private void ret(final int var) {
     methodVisitor.visitVarInsn(Opcodes.RET, var);
   }
 
-  private void ATHROW() {
+  private void athrow() {
     methodVisitor.visitInsn(Opcodes.ATHROW);
   }
 
-  private void ACONST_NULL() {
+  private void aconst_null() {
     methodVisitor.visitInsn(Opcodes.ACONST_NULL);
   }
 
-  private void RETURN() {
+  private void vreturn() {
     methodVisitor.visitInsn(Opcodes.RETURN);
   }
 
-  private void LABEL(final Label label) {
+  private void label(final Label label) {
     methodVisitor.visitLabel(label);
   }
 
-  private void IINC(final int var, final int increment) {
+  private void iinc(final int var, final int increment) {
     methodVisitor.visitIincInsn(var, increment);
   }
 
-  private void GOTO(final Label label) {
+  private void go(final Label label) {
     methodVisitor.visitJumpInsn(Opcodes.GOTO, label);
   }
 
-  private void JSR(final Label label) {
+  private void jsr(final Label label) {
     methodVisitor.visitJumpInsn(Opcodes.JSR, label);
   }
 
-  private void IFNONNULL(final Label label) {
+  private void ifnonnull(final Label label) {
     methodVisitor.visitJumpInsn(Opcodes.IFNONNULL, label);
   }
 
-  private void IFNE(final Label label) {
+  private void ifne(final Label label) {
     methodVisitor.visitJumpInsn(Opcodes.IFNE, label);
   }
 
-  private void TRYCATCH(final Label start, final Label end, final Label handler) {
+  private void trycatch(final Label start, final Label end, final Label handler) {
     methodVisitor.visitTryCatchBlock(start, end, handler, null);
   }
 
@@ -182,11 +201,11 @@ public class ClassWriterComputeMaxsTest {
         },
         0);
 
+    TestClassLoader loader = new TestClassLoader();
     try {
-      TestClassLoader loader = new TestClassLoader();
       loader.defineClass("C", classFile).newInstance();
-    } catch (Throwable t) {
-      fail(t.getMessage());
+    } catch (InstantiationException | IllegalAccessException e) {
+      fail(e.getMessage());
     }
   }
 
@@ -227,28 +246,19 @@ public class ClassWriterComputeMaxsTest {
     assertEquals(expected, actual);
   }
 
-  private static class TestClassLoader extends ClassLoader {
-
-    public TestClassLoader() {}
-
-    public Class<?> defineClass(final String name, final byte[] classFile) {
-      return defineClass(name, classFile, 0, classFile.length);
-    }
-  }
-
   /**
-   * Tests a method which has the most basic <code>try{}finally{}</code> form imaginable (repeated
-   * one or more times):
+   * Tests a method which has the most basic <code>try{}finally{}</code> form imaginable. That is,
+   * repeated one or more times:
    *
    * <pre>
    * public void a() {
-   *     int a = 0;
-   *     try {
-   *         a++;
-   *     } finally {
-   *         a--;
-   *     }
-   *     // ... same try {} finally {} repeated 0 or more times ...
+   *   int a = 0;
+   *   try {
+   *     a++;
+   *   } finally {
+   *     a--;
+   *   }
+   *   // ... same try {} finally {} repeated 0 or more times ...
    * }
    * </pre>
    */
@@ -256,45 +266,44 @@ public class ClassWriterComputeMaxsTest {
   @ValueSource(ints = {1, 31, 32, 33})
   public void testBasic(final int numSubroutines) {
     for (int i = 0; i < numSubroutines; ++i) {
-      Label L0 = new Label();
-      Label L1 = new Label();
-      Label L2 = new Label();
-      Label L3 = new Label();
-      Label L4 = new Label();
+      iconst_0(); // N0
+      istore(1);
 
-      ICONST_0(); // N0
-      ISTORE(1);
+      // Body of try block.
+      Label k0 = new Label();
+      label(k0); // N2
+      iinc(1, 1);
+      Label k3 = new Label();
+      go(k3);
 
-      // L0: body of try block.
-      LABEL(L0); // N2
-      IINC(1, 1);
-      GOTO(L1);
+      // Exception handler.
+      Label k1 = new Label();
+      label(k1); // N8
+      astore(3);
+      Label k2 = new Label();
+      jsr(k2);
+      aload(3); // N12
+      athrow();
 
-      // L2: exception handler.
-      LABEL(L2); // N8
-      ASTORE(3);
-      JSR(L3);
-      ALOAD(3); // N12
-      ATHROW();
+      // Subroutine.
+      label(k2); // N14
+      astore(2);
+      iinc(1, -1);
+      push();
+      push();
+      ret(2);
 
-      // L3: subroutine.
-      LABEL(L3); // N14
-      ASTORE(2);
-      IINC(1, -1);
-      PUSH();
-      PUSH();
-      RET(2);
+      // Non-exceptional exit from try block.
+      label(k3); // N22
+      jsr(k2);
+      push(); // N25
+      push();
+      Label k4 = new Label();
+      label(k4); // N27
+      vreturn();
 
-      // L1: non-exceptional exit from try block.
-      LABEL(L1); // N22
-      JSR(L3);
-      PUSH(); // N25
-      PUSH();
-      LABEL(L4); // N27
-      RETURN();
-
-      TRYCATCH(L0, L2, L2);
-      TRYCATCH(L1, L4, L2);
+      trycatch(k0, k1, k1);
+      trycatch(k3, k4, k1);
     }
 
     assertMaxs(4, 4);
@@ -312,73 +321,66 @@ public class ClassWriterComputeMaxsTest {
   }
 
   /**
-   * Tests a method which has an if/else-if w/in the finally clause:
+   * Tests a method which has an if/else-if w/in the finally clause. More specifically:
    *
    * <pre>
    * public void a() {
-   *     int a = 0;
-   *     try {
-   *         a++;
-   *     } finally {
-   *         if (a == 0)
-   *             a += 2;
-   *         else
-   *             a += 3;
+   *   int a = 0;
+   *   try {
+   *       a++;
+   *   } finally {
+   *     if (a == 0) {
+   *       a += 2;
+   *     } else {
+   *       a += 3;
    *     }
+   *   }
    * }
    * </pre>
    */
   @Test
   public void testIfElseInFinally() {
-    Label L0 = new Label();
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
-    Label L4 = new Label();
-    Label L5 = new Label();
-    Label L6 = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // Body of try block.
+    label(label0); // N2
+    iinc(1, 1);
+    go(label5);
 
-    // L0: body of try block.
-    LABEL(L0); // N2
-    IINC(1, 1);
-    GOTO(L1);
+    // Exception handler.
+    label(label1); // N8
+    astore(3);
+    jsr(label2);
+    push(); // N12
+    push();
+    aload(3);
+    athrow();
 
-    // L2: exception handler.
-    LABEL(L2); // N8
-    ASTORE(3);
-    JSR(L3);
-    PUSH(); // N12
-    PUSH();
-    ALOAD(3);
-    ATHROW();
+    // Subroutine.
+    label(label2); // N16
+    astore(2);
+    push();
+    push();
+    iload(1);
+    ifne(label3);
+    iinc(1, 2);
+    go(label4);
 
-    // L3: subroutine.
-    LABEL(L3); // N16
-    ASTORE(2);
-    PUSH();
-    PUSH();
-    ILOAD(1);
-    IFNE(L4);
-    IINC(1, 2);
-    GOTO(L5);
+    label(label3); // N29
+    iinc(1, 3);
 
-    LABEL(L4); // N29
-    IINC(1, 3);
+    label(label4); // N32, common exit.
+    ret(2);
 
-    LABEL(L5); // N32 common exit
-    RET(2);
+    // Non-exceptional exit from try block.
+    label(label5); // N34
+    jsr(label2);
+    label(label6); // N37
+    vreturn();
 
-    // L1: non-exceptional exit from try block.
-    LABEL(L1); // N34
-    JSR(L3);
-    LABEL(L6); // N37
-    RETURN();
-
-    TRYCATCH(L0, L2, L2);
-    TRYCATCH(L1, L6, L2);
+    trycatch(label0, label1, label1);
+    trycatch(label5, label6, label1);
 
     assertMaxs(5, 4);
     assertGraph(
@@ -394,78 +396,71 @@ public class ClassWriterComputeMaxsTest {
   }
 
   /**
-   * Tests a simple nested finally:
+   * Tests a simple nested finally. More specifically:
    *
    * <pre>
    * public void a1() {
-   *     int a = 0;
+   *   int a = 0;
+   *   try {
+   *     a += 1;
+   *   } finally {
    *     try {
-   *         a += 1;
+   *       a += 2;
    *     } finally {
-   *         try {
-   *             a += 2;
-   *         } finally {
-   *             a += 3;
-   *         }
+   *       a += 3;
    *     }
+   *   }
    * }
    * </pre>
    */
   @Test
   public void testSimpleNestedFinally() {
-    Label L0 = new Label();
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
-    Label L4 = new Label();
-    Label L5 = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // Body of try block.
+    label(label0); // N2
+    iinc(1, 1);
+    jsr(label2);
+    go(label5); // N8
 
-    // L0: Body of try block.
-    LABEL(L0); // N2
-    IINC(1, 1);
-    JSR(L3);
-    GOTO(L1); // N8
+    // First exception handler.
+    label(label1); // N11
+    astore(4);
+    jsr(label2);
+    aload(4); // N16
+    athrow();
 
-    // L2: First exception handler.
-    LABEL(L2); // N11
-    ASTORE(4);
-    JSR(L3);
-    ALOAD(4); // N16
-    ATHROW();
+    // First subroutine.
+    label(label2); // N19
+    astore(2);
+    iinc(1, 2);
+    jsr(label4);
+    push(); // N26
+    push();
+    ret(2);
 
-    // L3: First subroutine.
-    LABEL(L3); // N19
-    ASTORE(2);
-    IINC(1, 2);
-    JSR(L4);
-    PUSH(); // N26
-    PUSH();
-    RET(2);
+    // Second exception handler.
+    label(label3); // N30
+    astore(5);
+    jsr(label4);
+    aload(5); // N35
+    athrow();
 
-    // L5: Second exception handler;
-    LABEL(L5); // N30
-    ASTORE(5);
-    JSR(L4);
-    ALOAD(5); // N35
-    ATHROW();
+    // Second subroutine.
+    label(label4); // N38
+    astore(3);
+    push();
+    push();
+    iinc(1, 3);
+    ret(3);
 
-    // L4: Second subroutine.
-    LABEL(L4); // N38
-    ASTORE(3);
-    PUSH();
-    PUSH();
-    IINC(1, 3);
-    RET(3);
+    // On normal exit, try block jumps here.
+    label(label5); // N46
+    vreturn();
 
-    // L1: On normal exit, try block jumps here:
-    LABEL(L1); // N46
-    RETURN();
-
-    TRYCATCH(L0, L2, L2);
-    TRYCATCH(L3, L5, L5);
+    trycatch(label0, label1, label1);
+    trycatch(label2, label3, label3);
 
     assertMaxs(5, 6);
     assertGraph(
@@ -491,59 +486,52 @@ public class ClassWriterComputeMaxsTest {
    *
    * <pre>
    * public void a1() {
-   *     int a = 0;
-   *     while (true) {
-   *         try {
-   *             a += 1;
-   *         } finally {
-   *             a += 2;
-   *             break;
-   *         }
+   *   int a = 0;
+   *   while (true) {
+   *     try {
+   *       a += 1;
+   *     } finally {
+   *       a += 2;
+   *       break;
    *     }
+   *   }
    * }
    * </pre>
    */
   @Test
   public void testSubroutineWithNoRet() {
-    Label L0 = new Label();
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
-    Label L4 = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // While loop header/try block.
+    label(label0); // N2
+    iinc(1, 1);
+    jsr(label2);
+    go(label3); // N8
 
-    // L0: while loop header/try block.
-    LABEL(L0); // N2
-    IINC(1, 1);
-    JSR(L1);
-    GOTO(L2); // N8
+    // Implicit catch block.
+    label(label1); // N11
+    astore(2);
+    jsr(label2);
+    push(); // N15
+    push();
+    aload(2);
+    athrow();
 
-    // L3: implicit catch block.
-    LABEL(L3); // N11
-    ASTORE(2);
-    JSR(L1);
-    PUSH(); // N15
-    PUSH();
-    ALOAD(2);
-    ATHROW();
+    // Subroutine which does not return.
+    label(label2); // N19
+    astore(3);
+    iinc(1, 2);
+    go(label4);
 
-    // L1: subroutine which does not return.
-    LABEL(L1); // N19
-    ASTORE(3);
-    IINC(1, 2);
-    GOTO(L4);
+    // End of the loop, goes back to the top.
+    label(label3); // N26
+    go(label0);
 
-    // L2: end of the loop, goes back to the top.
-    LABEL(L2); // N26
-    GOTO(L0);
+    label(label4); // N29
+    vreturn();
 
-    // L4:
-    LABEL(L4); // N29
-    RETURN();
-
-    TRYCATCH(L0, L3, L3);
+    trycatch(label0, label1, label1);
 
     assertMaxs(1, 4);
     assertGraph(
@@ -554,28 +542,25 @@ public class ClassWriterComputeMaxsTest {
    * This tests a subroutine which has no ret statement, but ends in a "return" instead.
    *
    * <pre>
-   *   ACONST_NULL
-   *   JSR L0
-   * L0:
-   *   ASTORE 0
-   *   ASTORE 0
-   *   RETURN
+   *   aconst_null
+   *   jsr l0
+   * l0:
+   *   astore 0
+   *   astore 0
+   *   return
    * </pre>
    */
   @Test
   public void testSubroutineWithNoRet2() {
-    Label L0 = new Label();
-    Label L1 = new Label();
-
-    ACONST_NULL(); // N0
-    JSR(L0);
-    NOP(); // N4
-    LABEL(L0); // N5
-    ASTORE(0);
-    ASTORE(0);
-    RETURN();
-    LABEL(L1); // N8
-    methodVisitor.visitLocalVariable("i", "I", null, L0, L1, 1);
+    aconst_null(); // N0
+    jsr(label0);
+    nop(); // N4
+    label(label0); // N5
+    astore(0);
+    astore(0);
+    vreturn();
+    label(label1); // N8
+    methodVisitor.visitLocalVariable("i", "I", null, label0, label1, 1);
 
     assertMaxs(2, 2);
     assertGraph("N0=N5", "N4=N5", "N5=", "N8=");
@@ -591,65 +576,57 @@ public class ClassWriterComputeMaxsTest {
    *
    * <pre>
    * public void a1() {
-   *     int a = 0;
-   *     while (null == null) {
-   *         try {
-   *             a += 1;
-   *         } finally {
-   *             a += 2;
-   *             break;
-   *         }
+   *   int a = 0;
+   *   while (null == null) {
+   *     try {
+   *       a += 1;
+   *     } finally {
+   *       a += 2;
+   *       break;
    *     }
+   *   }
    * }
    * </pre>
    */
   @Test
   public void testImplicitExit() {
-    Label L0 = new Label();
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
-    Label L4 = new Label();
-    Label L5 = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // While loop header.
+    label(label0); // N2
+    aconst_null();
+    ifnonnull(label5);
 
-    // L5: while loop header.
-    LABEL(L5); // N2
-    ACONST_NULL();
-    IFNONNULL(L4);
+    // Yry block.
+    label(label1); // N6
+    iinc(1, 1);
+    jsr(label3);
+    go(label4); // N12
 
-    // L0: try block.
-    LABEL(L0); // N6
-    IINC(1, 1);
-    JSR(L1);
-    GOTO(L2); // N12
+    // Implicit catch block.
+    label(label2); // N15
+    astore(2);
+    jsr(label3);
+    aload(2); // N19
+    push();
+    push();
+    athrow();
 
-    // L3: implicit catch block.
-    LABEL(L3); // N15
-    ASTORE(2);
-    JSR(L1);
-    ALOAD(2); // N19
-    PUSH();
-    PUSH();
-    ATHROW();
+    // Subroutine which does not return.
+    label(label3); // N23
+    astore(3);
+    iinc(1, 2);
+    go(label5);
 
-    // L1: subroutine which does not return.
-    LABEL(L1); // N23
-    ASTORE(3);
-    IINC(1, 2);
-    GOTO(L4);
+    // End of the loop, goes back to the top.
+    label(label4); // N30
+    go(label1);
 
-    // L2: end of the loop, goes back to the top.
-    LABEL(L2); // N30
-    GOTO(L0);
+    label(label5); // N33
+    vreturn();
 
-    // L4:
-    LABEL(L4); // N33
-    RETURN();
-
-    TRYCATCH(L0, L3, L3);
+    trycatch(label1, label2, label2);
 
     assertMaxs(1, 4);
     assertGraph(
@@ -670,99 +647,84 @@ public class ClassWriterComputeMaxsTest {
    *
    * <pre>
    * void m(boolean b) {
-   *     try {
+   *   try {
+   *     return;
+   *   } finally {
+   *     while (b) {
+   *       try {
    *         return;
-   *     } finally {
-   *         while (b) {
-   *             try {
-   *                 return;
-   *             } finally {
-   *                 // NOTE --- this break avoids the second return above (weird)
-   *                 if (b)
-   *                     break;
-   *             }
+   *       } finally {
+   *         // NOTE --- this break avoids the second return above (weird)
+   *         if (b) {
+   *           break;
    *         }
+   *       }
    *     }
+   *   }
    * }
    * </pre>
    *
-   * This example is from the paper, "Subroutine Inlining and Bytecode Abstraction to Simplify
+   * <p>This example is from the paper, "Subroutine Inlining and Bytecode Abstraction to Simplify
    * Static and Dynamic Analysis" by Cyrille Artho and Armin Biere.
    */
   @Test
   public void testImplicitExitToAnotherSubroutine() {
-    Label T1 = new Label();
-    Label C1 = new Label();
-    Label S1 = new Label();
-    Label L = new Label();
-    Label C2 = new Label();
-    Label S2 = new Label();
-    Label W = new Label();
-    Label X = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    // Variable numbers:
-    int b = 1;
-    int e1 = 2;
-    int e2 = 3;
-    int r1 = 4;
-    int r2 = 5;
+    // First try.
+    label(label0); // N2
+    jsr(label2);
+    vreturn(); // N5
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // Exception handler for first try.
+    label(label1); // N6
+    astore(LOCAL2);
+    jsr(label2);
+    push(); // N10
+    push();
+    aload(LOCAL2);
+    athrow();
 
-    // T1: first try.
-    LABEL(T1); // N2
-    JSR(S1);
-    RETURN(); // N5
+    // First finally handler.
+    label(label2); // N14
+    astore(LOCAL4);
+    push();
+    push();
+    go(label6);
 
-    // C1: exception handler for first try.
-    LABEL(C1); // N6
-    ASTORE(e1);
-    JSR(S1);
-    PUSH(); // N10
-    PUSH();
-    ALOAD(e1);
-    ATHROW();
+    // Body of while loop, also second try.
+    label(label3); // N21
+    jsr(label5);
+    vreturn(); // N24
 
-    // S1: first finally handler
-    LABEL(S1); // N14
-    ASTORE(r1);
-    PUSH();
-    PUSH();
-    GOTO(W);
+    // Exception handler for second try.
+    label(label4); // N25
+    astore(LOCAL3);
+    push();
+    push();
+    jsr(label5);
+    aload(LOCAL3); // N31
+    athrow();
 
-    // L: body of while loop, also second try;
-    LABEL(L); // N21
-    JSR(S2);
-    RETURN(); // N24
+    // Second finally handler.
+    label(label5); // N33
+    astore(LOCAL5);
+    iload(LOCAL1);
+    ifne(label7);
+    ret(LOCAL5);
 
-    // C2: exception handler for second try.
-    LABEL(C2); // N25
-    ASTORE(e2);
-    PUSH();
-    PUSH();
-    JSR(S2);
-    ALOAD(e2); // N31
-    ATHROW();
+    // Test for the while loop.
+    label(label6); // N41
+    iload(LOCAL1);
+    ifne(label3); // falls through to X.
 
-    // S2: second finally handler.
-    LABEL(S2); // N33
-    ASTORE(r2);
-    ILOAD(b);
-    IFNE(X);
-    RET(r2);
+    // Exit from finally block.
+    label(label7); // N45
+    ret(LOCAL4);
 
-    // W: test for the while loop.
-    LABEL(W); // N41
-    ILOAD(b);
-    IFNE(L); // falls through to X.
-
-    // X: exit from finally block.
-    LABEL(X); // N45
-    RET(r1);
-
-    TRYCATCH(T1, C1, C1);
-    TRYCATCH(L, C2, C2);
+    trycatch(label0, label1, label1);
+    trycatch(label3, label4, label4);
 
     assertMaxs(5, 6);
     assertGraph(
@@ -783,28 +745,24 @@ public class ClassWriterComputeMaxsTest {
 
   @Test
   public void testImplicitExitToAnotherSubroutine2() {
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
+    iconst_0(); // N0
+    istore(1);
+    jsr(label0);
+    vreturn(); // N5
 
-    ICONST_0(); // N0
-    ISTORE(1);
-    JSR(L1);
-    RETURN(); // N5
+    label(label0); // N6
+    astore(2);
+    jsr(label1);
+    go(label2); // N10
 
-    LABEL(L1); // N6
-    ASTORE(2);
-    JSR(L2);
-    GOTO(L3); // N10
+    label(label1); // N13
+    astore(3);
+    iload(1);
+    ifne(label2);
+    ret(3);
 
-    LABEL(L2); // N13
-    ASTORE(3);
-    ILOAD(1);
-    IFNE(L3);
-    RET(3);
-
-    LABEL(L3); // N20
-    RET(2);
+    label(label2); // N20
+    ret(2);
 
     assertMaxs(1, 4);
     assertGraph("N0=N6", "N5=", "N6=N13", "N10=N20", "N13=N20,N10", "N20=N5");
@@ -814,43 +772,38 @@ public class ClassWriterComputeMaxsTest {
    * This tests a simple subroutine where the control flow jumps back and forth between the
    * subroutine and the caller.
    *
-   * <p>This would not normally be produced by a java compiler.
+   * <p>This would not normally be produced by a Java compiler.
    */
   @Test
   public void testInterleavedCode() {
-    Label L1 = new Label();
-    Label L2 = new Label();
-    Label L3 = new Label();
-    Label L4 = new Label();
+    iconst_0(); // N0
+    istore(1);
+    jsr(label0);
+    go(label1); // N5
 
-    ICONST_0(); // N0
-    ISTORE(1);
-    JSR(L1);
-    GOTO(L2); // N5
+    // Subroutine 1.
+    label(label0); // N8
+    astore(2);
+    iinc(1, 1);
+    go(label2);
 
-    // L1: subroutine 1.
-    LABEL(L1); // N8
-    ASTORE(2);
-    IINC(1, 1);
-    GOTO(L3);
+    // Second part of main subroutine.
+    label(label1); // N15
+    iinc(1, 2);
+    go(label3);
 
-    // L2: second part of main subroutine.
-    LABEL(L2); // N15
-    IINC(1, 2);
-    GOTO(L4);
+    // Second part of subroutine 1.
+    label(label2); // N21
+    iinc(1, 4);
+    push();
+    push();
+    ret(2);
 
-    // L3: second part of subroutine 1.
-    LABEL(L3); // N21
-    IINC(1, 4);
-    PUSH();
-    PUSH();
-    RET(2);
-
-    // L4: third part of main subroutine.
-    LABEL(L4); // N28
-    PUSH();
-    PUSH();
-    RETURN();
+    // Third part of main subroutine.
+    label(label3); // N28
+    push();
+    push();
+    vreturn();
 
     assertMaxs(4, 3);
     assertGraph("N0=N8", "N5=N15", "N8=N21", "N15=N28", "N21=N5", "N28=");
@@ -862,107 +815,90 @@ public class ClassWriterComputeMaxsTest {
    *
    * <pre>
    * void m(int b) {
+   *   try {
    *     try {
+   *       return;
+   *     } finally {
+   *       while (b) {
    *         try {
-   *             return;
+   *           return;
    *         } finally {
-   *             while (b) {
-   *                 try {
-   *                     return;
-   *                 } finally {
-   *                     // NOTE --- this break avoids the second return above
-   *                     // (weird)
-   *                     if (b)
-   *                         break;
-   *                 }
-   *             }
+   *           // NOTE --- this break avoids the second return above (weird)
+   *           if (b) {
+   *             break;
+   *           }
    *         }
-   *     } catch (Exception e) {
-   *         b += 3;
-   *         return;
+   *       }
    *     }
+   *   } catch (Exception e) {
+   *     b += 3;
+   *     return;
+   *   }
    * }
    * </pre>
    */
   @Test
   public void testImplicitExitInTryCatch() {
-    Label T1 = new Label();
-    Label C1 = new Label();
-    Label S1 = new Label();
-    Label L = new Label();
-    Label C2 = new Label();
-    Label S2 = new Label();
-    Label W = new Label();
-    Label X = new Label();
-    Label OC = new Label();
+    iconst_0(); // N0
+    istore(1);
 
-    // Variable numbers:
-    int b = 1;
-    int e1 = 2;
-    int e2 = 3;
-    int r1 = 4;
-    int r2 = 5;
+    // First try.
+    label(label0); // N2
+    jsr(label2);
+    vreturn(); // N5
 
-    ICONST_0(); // N0
-    ISTORE(1);
+    // Exception handler for first try.
+    label(label1); // N6
+    astore(LOCAL2);
+    jsr(label2);
+    aload(LOCAL2); // N10
+    athrow();
 
-    // T1: first try:
-    LABEL(T1); // N2
-    JSR(S1);
-    RETURN(); // N5
+    // First finally handler.
+    label(label2); // N12
+    astore(LOCAL4);
+    go(label6);
 
-    // C1: exception handler for first try.
-    LABEL(C1); // N6
-    ASTORE(e1);
-    JSR(S1);
-    ALOAD(e1); // N10
-    ATHROW();
+    // Body of while loop, also second try.
+    label(label3); // N17
+    jsr(label5);
+    push(); // N20
+    push();
+    vreturn();
 
-    // S1: first finally handler.
-    LABEL(S1); // N12
-    ASTORE(r1);
-    GOTO(W);
+    // Exception handler for second try.
+    label(label4); // N23
+    astore(LOCAL3);
+    jsr(label5);
+    aload(LOCAL3); // N27
+    athrow();
 
-    // L: body of while loop, also second try.
-    LABEL(L); // N17
-    JSR(S2);
-    PUSH(); // N20
-    PUSH();
-    RETURN();
+    // Second finally handler.
+    label(label5); // N29
+    astore(LOCAL5);
+    iload(LOCAL1);
+    ifne(label7);
+    push();
+    push();
+    ret(LOCAL5);
 
-    // C2: exception handler for second try.
-    LABEL(C2); // N23
-    ASTORE(e2);
-    JSR(S2);
-    ALOAD(e2); // N27
-    ATHROW();
+    // Test for the while loop.
+    label(label6); // N39
+    iload(LOCAL1);
+    ifne(label3); // Falls through.
 
-    // S2: second finally handler.
-    LABEL(S2); // N29
-    ASTORE(r2);
-    ILOAD(b);
-    IFNE(X);
-    PUSH();
-    PUSH();
-    RET(r2);
+    // Exit from finally block.
+    label(label7); // N43
+    ret(LOCAL4);
 
-    // W: test for the while loop.
-    LABEL(W); // N39
-    ILOAD(b);
-    IFNE(L); // falls through to X.
+    // Outermost catch.
+    label(label8); // N45
+    iinc(LOCAL1, 3);
+    vreturn();
 
-    // X: exit from finally block.
-    LABEL(X); // N43
-    RET(r1);
-
-    // OC: outermost catch.
-    LABEL(OC); // N45
-    IINC(b, 3);
-    RETURN();
-
-    TRYCATCH(T1, C1, C1);
-    TRYCATCH(L, C2, C2);
-    TRYCATCH(T1, OC, OC);
+    trycatch(label0, label1, label1);
+    trycatch(label3, label4, label4);
+    trycatch(label0, label8, label8);
 
     assertMaxs(4, 6);
     assertGraph(
@@ -988,68 +924,54 @@ public class ClassWriterComputeMaxsTest {
    */
   @Test
   public void testGlassFish2CorbaClientDelegateImplExample() {
-    Label l0 = new Label();
-    Label l1 = new Label();
-    Label l2 = new Label();
-    Label l3 = new Label();
-    Label l4 = new Label();
-    Label l5 = new Label();
-    Label l6 = new Label();
-    Label l7 = new Label();
-    Label l8 = new Label();
-    Label l9 = new Label();
-    Label l10 = new Label();
-    Label l11 = new Label();
-    Label l12 = new Label();
+    label(label0); // N0
+    jsr(label4);
+    label(label1); // N3
+    go(label5);
+    label(label2); // N6
+    pop();
+    jsr(label4);
+    label(label3); // N10
+    aconst_null();
+    athrow();
+    label(label4); // N12
+    astore(1);
+    ret(1);
+    label(label5); // N15
+    aconst_null();
+    aconst_null();
+    aconst_null();
+    pop();
+    pop();
+    pop();
+    label(label6); // N21
+    go(label8);
+    label(label7); // N24
+    pop();
+    go(label8);
+    aconst_null();
+    athrow();
+    label(label8); // N30
+    iconst_0();
+    ifne(label0);
+    jsr(label12);
+    label(label9); // N37
+    vreturn();
+    label(label10); // N38
+    pop();
+    jsr(label12);
+    label(label11); // N42
+    aconst_null();
+    athrow();
+    label(label12); // N44
+    astore(2);
+    ret(2);
 
-    LABEL(l0); // N0
-    JSR(l9);
-    LABEL(l1); // N3
-    GOTO(l10);
-    LABEL(l2); // N6
-    POP();
-    JSR(l9);
-    LABEL(l3); // N10
-    ACONST_NULL();
-    ATHROW();
-    LABEL(l9); // N12
-    ASTORE(1);
-    RET(1);
-    LABEL(l10); // N15
-    ACONST_NULL();
-    ACONST_NULL();
-    ACONST_NULL();
-    POP();
-    POP();
-    POP();
-    LABEL(l4); // N21
-    GOTO(l11);
-    LABEL(l5); // N24
-    POP();
-    GOTO(l11);
-    ACONST_NULL();
-    ATHROW();
-    LABEL(l11); // N30
-    ICONST_0();
-    IFNE(l0);
-    JSR(l12);
-    LABEL(l6); // N37
-    RETURN();
-    LABEL(l7); // N38
-    POP();
-    JSR(l12);
-    LABEL(l8); // N42
-    ACONST_NULL();
-    ATHROW();
-    LABEL(l12); // N44
-    ASTORE(2);
-    RET(2);
-
-    TRYCATCH(l0, l1, l2);
-    TRYCATCH(l2, l3, l2);
-    TRYCATCH(l0, l4, l5);
-    TRYCATCH(l0, l6, l7);
-    TRYCATCH(l7, l8, l7);
+    trycatch(label0, label1, label2);
+    trycatch(label2, label3, label2);
+    trycatch(label0, label6, label7);
+    trycatch(label0, label9, label10);
+    trycatch(label10, label11, label10);
 
     assertMaxs(3, 3);
     assertGraph(
@@ -1074,33 +996,27 @@ public class ClassWriterComputeMaxsTest {
    */
   @Test
   public void testImplicitExitToAnotherSubroutineInverted() {
-    Label l1 = new Label();
-    Label l2 = new Label();
-    Label l3 = new Label();
-    Label l4 = new Label();
-    Label l5 = new Label();
-
-    GOTO(l4); // N0
+    go(label3); // N0
     // Second subroutine, returns to caller of first subroutine.
-    LABEL(l2); // N3
-    ASTORE(2);
-    LABEL(l3); // N4
-    RET(1);
+    label(label0); // N3
+    astore(2);
+    label(label1); // N4
+    ret(1);
     // First subroutine.
-    LABEL(l1); // N6
-    ASTORE(1);
-    ALOAD(0);
-    IFNONNULL(l3);
-    JSR(l2); // This JSR never returns, the following code is unreachable.
-    ACONST_NULL(); // N14
-    ACONST_NULL();
-    ACONST_NULL();
-    RETURN();
+    label(label2); // N6
+    astore(1);
+    aload(0);
+    ifnonnull(label1);
+    jsr(label0); // This JSR never returns, the following code is unreachable.
+    aconst_null(); // N14
+    aconst_null();
+    aconst_null();
+    vreturn();
     // Main "subroutine".
-    LABEL(l4); // N18
-    JSR(l1);
-    LABEL(l5); // N21
-    RETURN();
+    label(label3); // N18
+    jsr(label2);
+    label(label4); // N21
+    vreturn();
 
     assertMaxs(1, 3);
     assertGraph("N0=N18", "N3=N4", "N4=N21", "N6=N3,N4", "N14=", "N18=N6", "N21=");
@@ -1113,18 +1029,17 @@ public class ClassWriterComputeMaxsTest {
   @Test
   public void testComputeMaxsFromFramesWithDeadCode() {
     init(Opcodes.V1_7);
-    Label l0 = new Label();
 
-    RETURN();
+    vreturn();
     // With the default compute maxs algorithm, this dead code block is not considered for the
     // maximum stack size, which works fine for classes up to V1_6. Starting with V1_7, stack map
     // frames are mandatory, even for dead code, and the maximum stack size must take dead code into
     // account. Hopefully it can be computed from the stack map frames, and the instructions in
     // between (without any control flow graph construction or algorithm).
-    LABEL(l0);
+    label(label0);
     methodVisitor.visitFrame(Opcodes.F_SAME, 0, null, 0, null);
-    ACONST_NULL();
-    RETURN();
+    aconst_null();
+    vreturn();
 
     assertMaxs(1, 1);
   }
@@ -1132,15 +1047,23 @@ public class ClassWriterComputeMaxsTest {
   @Test
   public void testComputeMaxsFromFrameWithLong() {
     init(Opcodes.V1_7);
-    Label l0 = new Label();
 
     methodVisitor.visitMethodInsn(Opcodes.INVOKESTATIC, "ABC", "get", "()J", false);
-    GOTO(l0);
-    LABEL(l0);
+    go(label0);
+    label(label0);
     methodVisitor.visitFrame(Opcodes.F_NEW, 0, null, 1, new Object[] {Opcodes.LONG});
-    ACONST_NULL();
-    RETURN();
+    aconst_null();
+    vreturn();
 
     assertMaxs(3, 1);
   }
+
+  private static class TestClassLoader extends ClassLoader {
+
+    public TestClassLoader() {}
+
+    public Class<?> defineClass(final String name, final byte[] classFile) {
+      return defineClass(name, classFile, 0, classFile.length);
+    }
+  }
 }
